var group__explog__mat =
[
    [ "cbrt", "group__arith__func__cbrt.htm", "group__arith__func__cbrt" ],
    [ "erf", "group__arith__func__erf.htm", "group__arith__func__erf" ],
    [ "erfc", "group__arith__func__erfc.htm", "group__arith__func__erfc" ],
    [ "exp", "group__arith__func__exp.htm", "group__arith__func__exp" ],
    [ "expm1", "group__arith__func__expm1.htm", "group__arith__func__expm1" ],
    [ "factorial", "group__arith__func__factorial.htm", "group__arith__func__factorial" ],
    [ "lgamma", "group__arith__func__lgamma.htm", "group__arith__func__lgamma" ],
    [ "log", "group__arith__func__log.htm", "group__arith__func__log" ],
    [ "log10", "group__arith__func__log10.htm", "group__arith__func__log10" ],
    [ "log1p", "group__arith__func__log1p.htm", "group__arith__func__log1p" ],
    [ "log2", "group__arith__func__log2.htm", null ],
    [ "pow", "group__arith__func__pow.htm", "group__arith__func__pow" ],
    [ "pow2", "group__arith__func__pow2.htm", "group__arith__func__pow2" ],
    [ "root", "group__arith__func__root.htm", "group__arith__func__root" ],
    [ "rsqrt", "group__arith__func__rsqrt.htm", "group__arith__func__rsqrt" ],
    [ "sqrt", "group__arith__func__sqrt.htm", "group__arith__func__sqrt" ],
    [ "tgamma", "group__arith__func__tgamma.htm", "group__arith__func__tgamma" ]
];